


% new parameters of DC motor in EECS 461 Lab
% KM = 0.0389;     % N-m/A
% KV = 0.0388;     % V/rad/sec
% R = 1.23;        % ohm
% L = .00034;      % H
% J = 6.55e-06;    % N-m/rad/s^2
% B = 0.00131;     % N-m/(rad/sec)
%
% Maxon Motor Direct Drive Haptic Box January 2009
KM = 0.0302;     % N-m/A
KV = 0.0302;     % V/rad/sec
R = 0.317;        % ohm
L = .0000823;      % H
J = 1.38e-05;    % N-m/rad/s^2
B = 0.00131;     % N-m/(rad/sec)

% define Laplace variable used to specify transfer functions
% for example, the transfer function G(s) = 1/(5s+1)
% can be written G = 1/(5*s+1)
s = tf('s');  

% calculate the electrical transfer function in the forward path
% 1/(Ls+R)
FW_elect = ?

% calculate the mechanical transfer function in the forward path
% 1/(Js+B)
FW_mech = ?

% calculate the total forward path transfer function
FW = FW_elect*KM*FW_mech;


% calculate the complete DC motor transfer function from voltage to speed
%  FW/(1+FW*KV)
motor_speed_tf = ?

% compute DC gain in units of rad/sec
[magDCspeed,phaseDCspeed] = bode(motor_speed_tf,0); 

% convert DC gain into units of rev/sec
magDCspeed = magDCspeed/2/pi;

% evaluate the Bode frequency response numerically

omega_Hz = logspace(0,5);
omega = omega_Hz*2*pi;      % frequency vector in rad/sec

[mag_speed,phase_speed] = bode(motor_speed_tf,omega);

mag_speed = squeeze(mag_speed);
phase_speed = squeeze(phase_speed);


% calculate the complete DC motor transfer function from voltage to torque
%  FW_elect*KM/(1+FW*KV)
motor_torque_tf = ?

% compute DC gain 
[magDCtorque,phaseDCtorque] = bode(motor_torque_tf,0);  

% evaluate the Bode frequency response numerically

[mag_torque,phase_torque] = bode(motor_torque_tf,omega);

mag_torque = squeeze(mag_torque);
phase_torque = squeeze(phase_torque);




figure(1)
clf

subplot(2,1,1)
% note I divide mag_speed by 2pi to convert speed in rad/sec to speed in
% rev/sec
semilogx(omega_Hz,20*log10(mag_speed/2/pi),'-',omega_Hz,20*log10(mag_torque),'--')
ylabel('gain, db')
title('transfer function from V to speed (rev/sec) and torque (N-m)')
grid
legend('speed','torque')


subplot(2,1,2)

semilogx(omega_Hz,phase_speed,'-',omega_Hz,phase_torque,'--')
ylabel('phase, degrees')
xlabel('frequency, Hz')
grid
legend('speed','torque')


% plot gain in absolute units, not db

figure(2)
clf

 

loglog(omega_Hz, mag_speed/2/pi ,'-',omega_Hz, mag_torque,'--')
ylabel('gain, absolute')
title(['DC gains: speed (rev/sec) = ',num2str(magDCspeed,3),...
       ',  torque (N-m) = ',num2str(magDCtorque,3)])
grid
legend('speed','torque')
xlabel('frequency, Hz')
ylim([10^-5  10])