


% new parameters of DC motor in EECS 461 Lab
% KM = 0.0389;     % N-m/A
% KV = 0.0388;     % V/rad/sec
% R = 1.23;        % ohm
% L = .00034;      % H
% J = 6.55e-06;    % N-m/rad/s^2
% B = 0.00131;     % N-m/(rad/sec)
%
% Maxon Motor Direct Drive Haptic Box January 2009
KM = 0.0302;     % N-m/A
KV = 0.0302;     % V/rad/sec
R = 0.317;        % ohm
L = .0000823;      % H
J = 1.38e-05;    % N-m/rad/s^2
B = 0.00131;     % N-m/(rad/sec)

% define Laplace variable used to specify transfer functions
% for example, the transfer function G(s) = 1/(5s+1)
% can be written G = 1/(5*s+1)
s = tf('s');  

% calculate the electrical transfer function in the forward path
% 1/(Ls+R)
FW_elect = 1/(L*s+R);

% calculate the mechanical transfer function in the forward path
% 1/(Js+B)
FW_mech = 1/(J*s+B);

% calculate the total forward path transfer function
FW = FW_elect*KM*FW_mech;

% calculate the complete DC motor transfer function from load torque to
% speed
motor_speed_tf = -FW_mech/(1+FW*KV);

% compute DC gain in units of rad/sec
[magDCspeed,phaseDCspeed] = bode(motor_speed_tf,0); 

% convert DC gain into units of rev/sec
magDCspeed = magDCspeed/2/pi;

% evaluate the Bode frequency response numerically

omega_Hz = logspace(0,5);
omega = omega_Hz*2*pi;      % frequency vector in rad/sec

[mag_speed,phase_speed] = bode(motor_speed_tf,omega);

mag_speed = squeeze(mag_speed);
phase_speed = squeeze(phase_speed);


% calculate the complete DC motor transfer function from load torque to torque
%  FW_elect*KM/(1+FW*KV)
motor_torque_tf = FW_elect*FW_mech*KM*KV/(1+FW*KV);

% compute DC gain 
[magDCtorque,phaseDCtorque] = bode(motor_torque_tf,0);  

% evaluate the Bode frequency response numerically

[mag_torque,phase_torque] = bode(motor_torque_tf,omega);

mag_torque = squeeze(mag_torque);
phase_torque = squeeze(phase_torque);




figure(1)
clf

subplot(2,1,1)
% note I divide mag_speed by 2pi to convert speed in rad/sec to speed in
% rev/sec
semilogx(omega_Hz,20*log10(mag_speed/2/pi),'-',omega_Hz,20*log10(mag_torque),'--')
ylabel('gain, db')
title('transfer function from T_L to speed (rev/sec) and torque (N-m)')
grid
legend('speed','torque')


subplot(2,1,2)

semilogx(omega_Hz,phase_speed,'-',omega_Hz,phase_torque,'--')
ylabel('phase, degrees')
xlabel('frequency, Hz')
grid
legend('speed','torque')


% plot gain in absolute units, not db

figure(2)
clf

 

loglog(omega_Hz, mag_speed/2/pi ,'-',omega_Hz, mag_torque,'--')
ylabel('gain, absolute')
title(['DC gains for response to T_L: speed (rev/sec) = ',num2str(magDCspeed,4),...
       ',  torque (N-m) = ',num2str(magDCtorque,4)])
grid
legend('speed','torque')
xlabel('frequency, Hz')
ylim([10^-3  500])


%%%%%%%%  now compute the ones for V


% calculate the complete DC motor transfer function from voltage to speed
%  FW/(1+FW*KV)
motor_speed_tf = FW/(1+FW*KV);

% compute DC gain in units of rad/sec
[magDCspeed,phaseDCspeed] = bode(motor_speed_tf,0); 

% convert DC gain into units of rev/sec
magDCspeed = magDCspeed/2/pi;

% evaluate the Bode frequency response numerically

omega_Hz = logspace(0,5);
omega = omega_Hz*2*pi;      % frequency vector in rad/sec

[mag_speed,phase_speed] = bode(motor_speed_tf,omega);

mag_speed = squeeze(mag_speed);
phase_speed = squeeze(phase_speed);


% calculate the complete DC motor transfer function from voltage to torque
%  FW_elect*KM/(1+FW*KV)
motor_torque_tf = FW_elect*KM/(1+FW*KV);

% compute DC gain 
[magDCtorque,phaseDCtorque] = bode(motor_torque_tf,0);  

% evaluate the Bode frequency response numerically

[mag_torque,phase_torque] = bode(motor_torque_tf,omega);

mag_torque = squeeze(mag_torque);
phase_torque = squeeze(phase_torque);




figure(3)
clf

subplot(2,1,1)
% note I divide mag_speed by 2pi to convert speed in rad/sec to speed in
% rev/sec
semilogx(omega_Hz,20*log10(mag_speed/2/pi),'-',omega_Hz,20*log10(mag_torque),'--')
ylabel('gain, db')
title('transfer function from V to speed (rev/sec) and torque (N-m)')
grid
legend('speed','torque')


subplot(2,1,2)

semilogx(omega_Hz,phase_speed,'-',omega_Hz,phase_torque,'--')
ylabel('phase, degrees')
xlabel('frequency, Hz')
grid
legend('speed','torque')


% plot gain in absolute units, not db

figure(4)
clf

 

loglog(omega_Hz, mag_speed/2/pi ,'-',omega_Hz, mag_torque,'--')
ylabel('gain, absolute')
title(['DC gains for response to V: speed (rev/sec) = ',num2str(magDCspeed,4),...
       ',  torque (N-m) = ',num2str(magDCtorque,4)])
grid
legend('speed','torque')
xlabel('frequency, Hz')
ylim([10^-5  10])





% a vector of constant applied voltages
V = [5,10,15,20,25,30,35 ];

% a range of steady state speeds from which to compute steady state torque

%Omega_ss = linspace(0,200);    % speed in rad/sec as required by the units in the formula
Omega_ss = linspace(0,1000);    % speed in rad/sec as required by the units in the formula
Omega_ss_rps = Omega_ss/2/pi;  % in order to plot speed in rev/sec rather than in rad/sec

% compute speed-torque curve lines

for i = 1:length(V)
for j = 1:length(Omega_ss)    
   Torque_ss(i,j) = (KM/R)*V(i) - (KM*KV/R)*Omega_ss(j);
end
end

 



% compute steady state values of speed and torque for several
% values of constant applied torque

% TL must have FIVE torque values in it!!!!
% (to get the labels on the graph to work correctly)
%TL = [0 .1 .2 .5 .7];
TL = [0 .5 1 1.5 2];

for i = 1:length(V)
for j = 1:length(TL)
 Omega_ss_pt(i,j) = (KM*V(i)-R*TL(j))/(KM*KV+B*R);
 Torque_ss_pt(i,j) = KM*(V(i)*B+KV*TL(j))/(KM*KV+B*R);
end   
end 

Omega_ss_pt_rps = Omega_ss_pt/2/pi;
figure(5)
clf

% plot the specific points just computed
for i = 1:length(V)
 hold on
 plot(Omega_ss_pt_rps(i,1),Torque_ss_pt(i,1),'*',Omega_ss_pt_rps(i,2),Torque_ss_pt(i,2),'o',...
         Omega_ss_pt_rps(i,3),Torque_ss_pt(i,3),'x',Omega_ss_pt_rps(i,4),Torque_ss_pt(i,4),'d',...
         Omega_ss_pt_rps(i,5),Torque_ss_pt(i,5),'s')
 hold off 
end


xlabel('speed, rev/sec')
ylabel('torque, Newton-meters')
%axis([0 Omega_ss_rps(length(Omega_ss_rps)) 0 1.2])
axis([0 Omega_ss_rps(length(Omega_ss_rps)) 0 2.5])
 
legend(['T_L = ',num2str(TL(1))],['T_L = ',num2str(TL(2))],...
     ['T_L = ',num2str(TL(3))],['T_L = ',num2str(TL(4))],...
        ['T_L = ',num2str(TL(5))],2)

title(['V = [',num2str(V),']'])

% plot the torque speed curvesd computed for figure 1
hold on
for i = 1:length(V)
   plot(Omega_ss_rps,Torque_ss(i,:))
end
hold off




% parameters of DC motor in EECS 461 Lab
%KM = 0.0389;     % N-m/A
%KV = 0.0388;     % V/(rad/sec)
%R = 1.23;     % ohm
%L = .00034;    % H
%J = 6.55e-06;     % N-m/(rad/sec^2)
%B = 0.00131;   % N-m/(rad/sec)


tfinal = .3;  % time interval of the simulation (may need to be adjusted)

V = 10;            % input voltage turned on at t = tstep seconds
tstep = .1;   % time at which input voltage is applied
              

TL = .2;          % size of load torque  disturbance
load_time = .2;    % time that the load torque disturbance is applied

% call SIMULINK to perform simulation

 
sim('DC_motor_linear')

% note we plot 100*torque in order to compare torque and speed
% on the same scale
figure(6)
clf

plot(tout,yout(:,1)/2/pi,'-',tout,100*yout(:,2),'--')
legend('speed, rev/sec','100*torque, N-m',4)
title(['V = ',num2str(V),', T_L = ',num2str(TL)]) 
xlabel('time, seconds')
 %axis([0 tfinal 0 30])
 axis([0 tfinal 0 90])
grid
%set(gca,'YTick',0:2:30)
%set(gca,'YTick',0:2:90)